OC.L10N.register(
    "photos",
    {
    "Public link" : "Liga pública",
    "Photos" : "Fotos",
    "Videos" : "Videos",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "Shared by" : "Compartido por",
    "Group" : "Grupo",
    "Favorite" : "Favorito",
    "Go back" : "Regresar",
    "Dates" : "Fechas",
    "Home" : "Inicio",
    "Remove from favorites" : "Eliminar de favoritos",
    "Details" : "Detalles",
    "Add" : "Agregar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
